@@ -159,11 +159,6 @@ LANGUAGE = click.option(
     '-l', '--language', required=False, default=None, type=click.STRING, metavar='<string>',
     help="Programming language of code"
 )
-MEMORY_ALLOCATION = click.option(
-    '-mem', '--memory_allocation', required=False, default=None, type=int, metavar='<int>',
-    help="[DEPRECATED] The reserved memory allocation for the version - deprecated and will be overruled by "
-         "`instance_type`"
-)
 INSTANCE_TYPE = click.option(
     '-inst', '--instance_type', required=False, default=None, type=click.STRING, metavar='<string>',
     help="Reserved instance type for the version"
@@ -203,7 +198,7 @@ MAX_QUEUE_SIZE_BATCH = click.option(
     help="Maximum number of queued batch requests to the version"
 )
 VERSION_STATIC_IP = click.option(
-    '--static-ip', required=False, metavar='<bool>', default=False,
+    '--static-ip', required=False, metavar='<bool>', default=False, type=click.BOOL,
     help="Whether the deployment version should get a static IP"
 )
 
