@@ -4,6 +4,7 @@ from ubiops_cli.utils import init_client, read_yaml, write_yaml, get_current_pro
 from ubiops_cli.src.helpers.pipeline_helpers import rename_pipeline_object_reference_version, \
     set_pipeline_version_defaults, PIPELINE_VERSION_FIELDS, PIPELINE_VERSION_FIELDS_RENAMED
 from ubiops_cli.src.helpers.helpers import get_label_filter
+from ubiops_cli.src.helpers.pipeline_helpers import format_pipeline_object_configuration
 from ubiops_cli.src.helpers.formatting import print_list, print_item, format_yaml
 from ubiops_cli.src.helpers.options import *
 
@@ -96,6 +97,7 @@ def pipeline_versions_get(pipeline_name, version_name, output_path, quiet, forma
     objects:
       - name: object1
         reference_name: my-deployment-name
+        reference_type: deployment
         reference_version: my-deployment-version
     attachments:
       - destination_name: object1
@@ -119,6 +121,7 @@ def pipeline_versions_get(pipeline_name, version_name, output_path, quiet, forma
     setattr(version, 'input_fields', pipeline.input_fields)
     setattr(version, 'output_type', pipeline.output_type)
     setattr(version, 'output_fields', pipeline.output_fields)
+    version.objects = format_pipeline_object_configuration(objects=version.objects)
 
     if output_path is not None:
         # Store only reusable settings
@@ -129,9 +132,10 @@ def pipeline_versions_get(pipeline_name, version_name, output_path, quiet, forma
                 'version', *PIPELINE_VERSION_FIELDS
             ],
             optional=[
-                'objects name', 'objects reference_name', 'objects version', 'attachments destination_name',
-                'attachments sources source_name', 'attachments sources mapping', 'input_fields name',
-                'input_fields data_type', 'output_fields name', 'output_fields data_type'
+                'objects name', 'objects reference_name', 'objects reference_type', 'objects version',
+                'objects configuration', 'attachments destination_name', 'attachments sources source_name',
+                'attachments sources mapping', 'input_fields name', 'input_fields data_type', 'output_fields name',
+                'output_fields data_type'
             ],
             rename={
                 'pipeline': 'pipeline_name',
@@ -156,8 +160,8 @@ def pipeline_versions_get(pipeline_name, version_name, output_path, quiet, forma
                 'version', *PIPELINE_VERSION_FIELDS
             ],
             optional=[
-                'creation_date', 'last_updated', 'objects name',
-                'objects reference_name', 'objects version', 'attachments destination_name',
+                'creation_date', 'last_updated', 'objects name', 'objects reference_type', 'objects reference_name',
+                'objects configuration', 'objects version', 'attachments destination_name',
                 'attachments sources source_name', 'attachments sources mapping', 'input_fields name',
                 'input_fields data_type', 'output_fields name', 'output_fields data_type'
             ],
@@ -201,6 +205,7 @@ def pipeline_versions_create(pipeline_name, version_name, yaml_file, format_, **
     objects:
       - name: object1
         reference_name: my-deployment-name
+        reference_type: deployment
         reference_version: my-deployment-version
     attachments:
       - destination_name: object1
@@ -238,6 +243,7 @@ def pipeline_versions_create(pipeline_name, version_name, yaml_file, format_, **
 
     version = api.PipelineVersionCreate(version=version_name, **{k: kwargs[k] for k in PIPELINE_VERSION_FIELDS})
     response = client.pipeline_versions_create(project_name=project_name, pipeline_name=pipeline_name, data=version)
+    response.objects = format_pipeline_object_configuration(objects=response.objects)
     client.api_client.close()
 
     print_item(
@@ -275,6 +281,7 @@ def pipeline_versions_update(pipeline_name, version_name, yaml_file, new_name, q
     objects:
       - name: object1
         reference_name: my-deployment-name
+        reference_type: deployment
         reference_version: my-deployment-version
     attachments:
       - destination_name: object1
@@ -307,6 +314,7 @@ def pipeline_versions_update(pipeline_name, version_name, yaml_file, new_name, q
     kwargs = rename_pipeline_object_reference_version(content=kwargs)
 
     version_data = api.PipelineVersionUpdate(**{'version': new_name, **{k: kwargs[k] for k in PIPELINE_VERSION_FIELDS}})
+    version_data.objects = format_pipeline_object_configuration(objects=version_data.objects)
     client.pipeline_versions_update(
         project_name=project_name,
         pipeline_name=pipeline_name,
